@@ -1,6 +1,5 @@
-from __future__ import absolute_import, division, print_function
-
-from stripe.error import StripeError
+from stripe._error import StripeError
+from stripe._error_object import OAuthErrorObject
 
 
 class OAuthError(StripeError):
@@ -17,6 +16,18 @@ class OAuthError(StripeError):
             description, http_body, http_status, json_body, headers, code
         )
 
+    def _construct_error_object(self):
+        if self.json_body is None:
+            return None
+
+        from stripe._api_requestor import _APIRequestor
+
+        return OAuthErrorObject._construct_from(
+            values=self.json_body,  # type: ignore
+            requestor=_APIRequestor._global_instance(),
+            api_mode="V1",
+        )
+
 
 class InvalidClientError(OAuthError):
     pass
